@@ -99,11 +99,13 @@ Cpalette::Cpalette(QWidget* parent) : QWidget(parent, "Cdouble")
 	gX1 = new MSpinBox( frame8, 2);
 	gX1->setDecimals(100);
 	gX1->setSuffix( tr( " pt" ) );
+	gX1->setMinValue(0);
 	gX1->setMaxValue(3000);
 	frame8Layout->addWidget( gX1, 0, 1 );
 	gY1 = new MSpinBox( frame8, 2 );
 	gY1->setSuffix( tr( " pt" ) );
 	gY1->setDecimals(100);
+	gY1->setMinValue(0);
 	gY1->setMaxValue(3000);
 	frame8Layout->addWidget( gY1, 1, 1 );
 	GTextX2 = new QLabel( frame8, "GTextX2" );
@@ -115,11 +117,13 @@ Cpalette::Cpalette(QWidget* parent) : QWidget(parent, "Cdouble")
 	gX2 = new MSpinBox( frame8, 2 );
 	gX2->setSuffix( tr( " pt" ) );
 	gX2->setDecimals(100);
+	gX2->setMinValue(0);
 	gX2->setMaxValue(3000);
 	frame8Layout->addWidget( gX2, 0, 3 );
 	gY2 = new MSpinBox( frame8, 2 );
 	gY2->setSuffix( tr( " pt" ) );
 	gY2->setDecimals(100);
+	gY2->setMinValue(0);
 	gY2->setMaxValue(3000);
 	frame8Layout->addWidget( gY2, 1, 3 );
 	GradLayout->addWidget( frame8 );
@@ -466,6 +470,10 @@ void Cpalette::setSpecialGradient(double x1, double y1, double x2, double y2, do
 	gX2->setMaxValue(w);
 	gY1->setMaxValue(h);
 	gY2->setMaxValue(h);
+	gX1->setMinValue(0);
+	gX2->setMinValue(0);
+	gY1->setMinValue(0);
+	gY2->setMinValue(0);
 	gX1->setValue(x1);
 	gX2->setValue(x2);
 	gY1->setValue(y1);
@@ -537,6 +545,10 @@ void Cpalette::UnitChange(double old, double neww, int ein)
 	gY1->setSuffix( einh );
 	gX2->setSuffix( einh );
 	gY2->setSuffix( einh );
+	gX1->setMinValue(0);
+	gX2->setMinValue(0);
+	gY1->setMinValue(0);
+	gY2->setMinValue(0);
 	gX1->setMaxValue(oldXM * neww);
 	gX1->setValue(oldX * neww);
 	gY1->setMaxValue(oldYM * neww);
