@@ -1,11 +1,11 @@
-/****************************************************************************
-**
-**
-** Created: Son Jun 2 11:23:14 2002
-**      by:  Franz Schmid
-**
-**
-****************************************************************************/
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include <qmessagebox.h>
 #include "layers.h"
 #include "layers.moc"
@@ -259,6 +259,7 @@ void LayerPalette::upLayer()
 	rebuildList();
 	emit LayerChanged();
 	MarkActiveLayer(*Activ);
+	emit LayerActivated(*Activ);
 	ScApp->slotDocCh();
 }
 
@@ -285,6 +286,7 @@ void LayerPalette::downLayer()
 	rebuildList();
 	emit LayerChanged();
 	MarkActiveLayer(*Activ);
+	emit LayerActivated(*Activ);
 	ScApp->slotDocCh();
 }
 
@@ -338,6 +340,7 @@ void LayerPalette::printLayer()
 
 void LayerPalette::MarkActiveLayer(int l)
 {
+	disconnect(Table, SIGNAL(currentChanged(int, int)), this, SLOT(setActiveLayer(int)));
 	QValueList<Layer>::iterator it;
 	for (it = layers->begin(); it != layers->end(); ++it)
 	{
@@ -345,6 +348,7 @@ void LayerPalette::MarkActiveLayer(int l)
 			break;
 	}
 	Table->setCurrentCell(layers->count()-1-(*it).Level, 0);
+	connect(Table, SIGNAL(currentChanged(int, int)), this, SLOT(setActiveLayer(int)));
 }
 
 void LayerPalette::setActiveLayer(int row)
