@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "mpalette.h"
 #include "mpalette.moc"
 #include <cmath>
@@ -81,6 +89,7 @@ void NameWidget::focusOutEvent(QFocusEvent *e)
 
 Mpalette::Mpalette( QWidget* parent, preV *Prefs) : QDialog( parent, "Mdouble", false, 0)
 {
+	setName("propertiesPalette");
 	setCaption( tr( "Properties" ) );
 	HaveDoc = false;
 	HaveItem = false;
@@ -475,7 +484,7 @@ Mpalette::Mpalette( QWidget* parent, preV *Prefs) : QDialog( parent, "Mdouble",
 	Fonts->setMaximumSize(190, 30);
 	layout41->addMultiCellWidget( Fonts, 0, 0, 0, 1 );
 
-	Size = new MSpinBox( 1, 1024, page_3, 1 );
+	Size = new MSpinBox( 0.5, 1024, page_3, 1 );
 	Size->setPrefix( "" );
 	Size->setSuffix( tr( " pt" ) );
 	fontsizeLabel = new QLabel( Size, tr("&Font Size:"), page_3, "fontsizeLabel" );
@@ -558,8 +567,8 @@ Mpalette::Mpalette( QWidget* parent, preV *Prefs) : QDialog( parent, "Mdouble",
 	Extra->setSuffix( tr( " pt" ) );
 	GroupBox3Layout->addWidget( Extra, 0, 1 );
 
-	kerningLabel = new QLabel( Extra, tr( "&Kerning:" ), GroupBox3, "kerningLabel" );
-	GroupBox3Layout->addWidget( kerningLabel, 0, 0 );
+	trackingLabel = new QLabel( Extra, tr( "Trac&king:" ), GroupBox3, "trackingLabel" );
+	GroupBox3Layout->addWidget( trackingLabel, 0, 0 );
 
 	linespacingLabel = new QLabel( LineSp, tr( "L&ine Spacing:" ), GroupBox3, "linespacingLabel" );
 	GroupBox3Layout->addWidget( linespacingLabel, 1, 0 );
@@ -785,7 +794,7 @@ Mpalette::Mpalette( QWidget* parent, preV *Prefs) : QDialog( parent, "Mdouble",
 	QToolTip::add( PM1, tr( "Saturation of color of text stroke" ) );
 	QToolTip::add( PM2, tr( "Saturation of color of text fill" ) );
 	QToolTip::add( Revert, tr( "Right to Left Writing" ) );
-	QToolTip::add( Extra, tr( "Manual Kerning" ) );
+	QToolTip::add( Extra, tr( "Manual Tracking" ) );
 	QToolTip::add( LineSp, tr( "Line Spacing" ) );
 	QToolTip::add( Spal, tr( "Style of current paragraph" ) );
 	QToolTip::add( langCombo, tr( "Hyphenation language of frame" ) );
@@ -987,7 +996,7 @@ void Mpalette::SetDoc(ScribusDoc *d)
 	Rot->setValues( 0, 360, 100, 0);
 	RoundRect->setValues( -300, 300, 10, 0);
 	Extra->setValues( -300, 300, 10, 0);
-	Size->setValues( 1, 1024, 10, 1);
+	Size->setValues( 0.5, 1024, 10, 1);
 	LineSp->setValues( 1, 300, 10, 1);
 	ScaleX->setValues( 1, 3000, 10, 1);
 	ScaleY->setValues( 1, 3000, 10, 1);
@@ -1128,11 +1137,6 @@ void Mpalette::SetCurItem(PageItem *i)
 		Width->setReadOnly(setter);
 		Height->setReadOnly(setter);
 	}
-	if (i->Locked)
-	{
-		HaveItem = true;
-		return;
-	}
 	if (i->PType == 8)
 	{
 		TabStack2->raiseWidget(1);
@@ -1169,7 +1173,7 @@ void Mpalette::SetCurItem(PageItem *i)
 	if (i->PType == 5)
 	{
 		Kette2->setEnabled(false);
-		if (LMode)
+		if (LMode && !i->Locked)
 			Height->setEnabled(true);
 		else
 			Height->setEnabled(false);
@@ -1475,13 +1479,13 @@ void Mpalette::UnitChange()
 	Width->setValues( UmReFaktor, maxXYWHVal, xywhdecimals, newW );
 	Height->setValues( UmReFaktor, maxXYWHVal, xywhdecimals, newH );
 
-	LXpos->setMaxValue( maxXYWHVal );
 	LXpos->setDecimals(xywhdecimals);
+	LXpos->setMaxValue( maxXYWHVal );
 	LXpos->setValue(newLX);
 
-	LYpos->setValue(newLY);
 	LYpos->setDecimals(xywhdecimals);
 	LYpos->setMaxValue( maxXYWHVal );
+	LYpos->setValue(newLY);
 
 	DGap->setDecimals(distdecimals);
 	DGap->setMaxValue(newGM);
@@ -3120,8 +3124,8 @@ void Mpalette::handlePathDist()
 	if ((HaveDoc) && (HaveItem))
 	{
 		CurItem->Extra = Dist->value();
-		doc->ActPage->UpdatePolyClip(CurItem);
 		doc->ActPage->AdjustItemSize(CurItem);
+		doc->ActPage->UpdatePolyClip(CurItem);
 		doc->ActPage->RefreshItem(CurItem);
 		emit DocChanged();
 	}
@@ -3134,8 +3138,8 @@ void Mpalette::handlePathOffs()
 	if ((HaveDoc) && (HaveItem))
 	{
 		CurItem->BaseOffs = -LineW->value();
-		doc->ActPage->UpdatePolyClip(CurItem);
 		doc->ActPage->AdjustItemSize(CurItem);
+		doc->ActPage->UpdatePolyClip(CurItem);
 		doc->ActPage->RefreshItem(CurItem);
 		emit DocChanged();
 	}
@@ -3143,7 +3147,7 @@ void Mpalette::handlePathOffs()
 
 void Mpalette::NewName()
 {
-	if (ScApp->ScriptRunning)
+	if (ScApp->ScriptRunning || !HaveDoc || !HaveItem)
 		return;
 	QString NameOld = CurItem->AnName;
 	QString NameNew = NameEdit->text();
