@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #ifndef MPALETTE_H
 #define MPALETTE_H
 
@@ -189,7 +197,7 @@ public:
 	QLabel* bottomLabel;
 	QLabel* leftLabel;
 	QLabel* rightLabel;
-	QLabel* kerningLabel;
+	QLabel* trackingLabel;
 	QLabel* linespacingLabel;
 	QLabel* fontsizeLabel;
 	QLabel* yscaleLabel;
