@@ -48,9 +48,12 @@ SxwDialog::SxwDialog(bool update, bool prefix, bool pack) : QDialog(0, "sxwdia",
 	blayout->addStretch(10);
 	okButton = new QPushButton(tr("OK"), this, "okButton");
 	blayout->addWidget(okButton);
+	cancelButton = new QPushButton(tr("Cancel"), this, "cancelButton");
+	blayout->addWidget(cancelButton);
 	layout->addLayout(blayout);
 
 	connect(okButton, SIGNAL(clicked()), this, SLOT(accept()));
+	connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
 }
 
 bool SxwDialog::shouldUpdate()
