@@ -1,3 +1,11 @@
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
 #include "cmdobj.h"
 #include "cmdutil.h"
 
@@ -489,7 +497,7 @@ PyObject *scribus_setstyle(PyObject */*self*/, PyObject* args)
 		/*
 		 * First, find the style number associated with the requested style
 		 * by scanning through the styles looking for the name. If
-		 * we can't find it, raise PyExc_Exception.
+		 * we cannot find it, raise PyExc_Exception.
 		 * FIXME: Should use a more specific exception.
 		 */
 		bool found = false;
@@ -508,12 +516,16 @@ PyObject *scribus_setstyle(PyObject */*self*/, PyObject* args)
 			PyErr_SetString(NotFoundError, QObject::tr("Style not found","python error"));
 			return NULL;
 		}
+		
+		int Apm = Carrier->doc->AppMode;
+		if (item->HasSel)
+			Carrier->doc->AppMode = 7;
 		// quick hack to always apply on the right frame - pv
 		Carrier->doc->ActPage = item->OwnPage;
-		Carrier->doc->ActPage->Deselect(true);
 		Carrier->doc->ActPage->SelectItemNr(item->ItemNr);
-		// Now apply the style.
 		Carrier->setNewAbStyle(styleid);
+		Carrier->doc->AppMode = Apm;
+		Carrier->doc->ActPage->Deselect(true);
 	}
 	else
 	{
