@@ -3,7 +3,9 @@
 #include <qstring.h>
 #include <qobject.h>
 
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
 
 #include "scfonts_ttf.h"
 
@@ -50,6 +52,8 @@ bool Foi_ttf::ReadMetrics()
 	FPointArray outlines;
 	double x, y;
 	struct GlyphR GRec;
+	char *buf[50];
+	QString glyName = "";
 	error = FT_Init_FreeType( &library );
 	if (error)
 	{
@@ -66,6 +70,7 @@ bool Foi_ttf::ReadMetrics()
 	}
 	uniEM = static_cast<double>(face->units_per_EM);
 	HasKern = FT_HAS_KERNING(face);
+	HasNames = FT_HAS_GLYPH_NAMES(face);
 	Ascent = tmp.setNum(face->ascender * 1000 / uniEM);
 	Descender = tmp.setNum(face->descender * 1000 / uniEM);
 	CapHeight = Ascent;
@@ -103,6 +108,12 @@ bool Foi_ttf::ReadMetrics()
 			GRec.y = y;
 			GlyphArray.insert(charcode, GRec);
 		}
+/* The following lines are a check for some weired fonts which have invalid "post" tables */
+		FT_Get_Glyph_Name(face, gindex, buf, 50);
+		QString newName = QString(reinterpret_cast<char*>(buf));
+		if (newName == glyName)
+			HasNames = false;
+		glyName = newName;
 		charcode = FT_Get_Next_Char( face, charcode, &gindex );
 	}
 	FT_Done_FreeType( library );
