@@ -28,6 +28,7 @@ extern int moveFile(QString source, QString target);
 ScribusWin::ScribusWin(QWidget* parent, ScribusDoc* ddoc)
 		: QMainWindow(parent, "", WDestructiveClose)
 {
+	setName("documentWindow");
 	setIcon(loadIcon("AppIcon2.png"));
 	doc = ddoc;
 	muster = NULL;
@@ -70,7 +71,7 @@ void ScribusWin::closeEvent(QCloseEvent *ce)
 			CloseTxt = tr("&Leave Anyway");
 		else
 			CloseTxt = tr("C&lose Anyway");
-		int exit=QMessageBox::information(this,
+		int exit=QMessageBox::information(ScApp,
 		                                  tr("Warning"),
 		                                  tr("Document:")+" "+doc->DocName+"\n"+ tr("has been changed since the last save."),
 		                                  tr("&Save Now"),
@@ -81,21 +82,26 @@ void ScribusWin::closeEvent(QCloseEvent *ce)
 		{
 		case 0:
 			if (ScApp->DoSaveClose())
+			{
+				ScApp->DoFileClose();
 				ce->accept();
+			}
 			else
 				return;
 			break;
 		case 1:
 			break;
 		case 2:
-			emit Schliessen();
+			//emit Schliessen();
+			ScApp->DoFileClose();
 			ce->accept();
 			break;
 		}
 	}
 	else
 	{
-		emit Schliessen();
+		//emit Schliessen();
+		ScApp->DoFileClose();
 		ce->accept();
 	}
 }
