@@ -22,9 +22,15 @@ extern QPixmap loadIcon(QString nam);
  \retval None
  */
 SplashScreen::SplashScreen() 
-	: QWidget( 0, 0, WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WX11BypassWM )
+//	: QWidget( 0, 0, WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WX11BypassWM )
+	: QWidget( 0, 0, WStyle_Customize | WStyle_NoBorder | WStyle_StaysOnTop | WStyle_Tool | WStyle_Splash )
 {
 	pix = loadIcon("Splash.png");
+		if (pix.isNull()) 
+{
+		pix = QPixmap(360, 200);
+		pix.fill(Qt::darkGray);
+}
 	setErasePixmap( pix );
 	resize( pix.size() );
 	QRect scr = QApplication::desktop()->screenGeometry();
@@ -86,6 +92,7 @@ void SplashScreen::setStatus( const QString &message )
 	painter.setFont(QFont("Helvetica", 10));
 	painter.setPen( white );
 	painter.drawText( 10, textPix.height()-8, tmp );
+	painter.end();
 	setErasePixmap( textPix );
 	repaint();
 }
