@@ -25,6 +25,7 @@
 #include <qcolordialog.h>
 #include <qfontdialog.h>
 #include <qcursor.h>
+#include <qtextcodec.h>
 #include "serializer.h"
 #include "customfdialog.h"
 #include "search.h"
@@ -168,6 +169,18 @@ SEditor::SEditor(QWidget* parent, ScribusDoc *docc) : QTextEdit(parent)
 	connect(QApplication::clipboard(), SIGNAL(selectionChanged()), this, SLOT(SelClipChange()));
 }
 
+void SEditor::imEndEvent(QIMEvent *e)
+{
+	QString uc = e->text();
+	if ((uc != "") && ((*doc->AllFonts)[CurrFont]->CharWidth.contains(uc[0].unicode())))
+	{
+		insChars(e->text());
+		QTextEdit::imEndEvent(e);
+		emit SideBarUp(true);
+		emit SideBarUpdate();
+	}
+}
+
 void SEditor::keyPressEvent(QKeyEvent *k)
 {
 	emit SideBarUp(false);
@@ -196,6 +209,13 @@ void SEditor::keyPressEvent(QKeyEvent *k)
 		emit SideBarUp(true);
 		return;
 	}
+	if ((k->key() + KeyMod) == ScApp->Prefs.KeyActions[67].KeyID)
+	{
+		insChars(QString(QChar(29)));
+		insert("_");
+		emit SideBarUp(true);
+		return;
+	}
 	QString uc = k->text();
 	switch (k->state())
 	{
@@ -203,6 +223,45 @@ void SEditor::keyPressEvent(QKeyEvent *k)
 		case ControlButton|ShiftButton:
 		case ControlButton|Keypad:
 		case ControlButton|ShiftButton|Keypad:
+			switch (k->key())
+			{
+				case Key_Delete:
+					moveCursor(QTextEdit::MoveWordForward, true);
+					deleteSel();
+					break;
+				case Key_Backspace:
+					moveCursor(QTextEdit::MoveWordBackward, true);
+					deleteSel();
+					break;
+				case Key_K:
+					moveCursor(QTextEdit::MoveLineEnd, true);
+					deleteSel();
+					break;
+				case Key_D:
+					moveCursor(QTextEdit::MoveForward, true);
+					deleteSel();
+					break;
+				case Key_H:
+					moveCursor(QTextEdit::MoveBackward, true);
+					deleteSel();
+					break;
+				case Key_X:
+					cut();
+					return;
+					break;
+				case Key_V:
+					paste();
+					return;
+					break;
+				case Key_Y:
+				case Key_Z:
+					emit SideBarUp(true);
+					return;
+					break;
+				case Key_C:
+					copyStyledText();
+					break;
+			}
 			break;
 		case NoButton:
 		case Keypad:
@@ -245,6 +304,9 @@ void SEditor::keyPressEvent(QKeyEvent *k)
 			wasMod = false;
 			switch (k->key())
 			{
+				case Key_Escape:
+					k->ignore();
+					break;
 				case Key_Shift:
 				case Key_Control:
 				case Key_Alt:
@@ -707,6 +769,7 @@ void SEditor::setAlign(int style)
 
 void SEditor::loadItemText(PageItem* b)
 {
+	setUpdatesEnabled(false);
 	struct PtiSmall *hg;
 	QString Text = "";
 	QString Ccol = "";
@@ -788,6 +851,17 @@ void SEditor::loadItemText(PageItem* b)
 						chars->append(hg);
 						continue;
 					}
+					else if (hg->ch == QChar(29))
+					{
+						setFarbe(Ccol, Csha);
+						setAlign(Ali);
+						setStyle(Csty);
+						insert(Text);
+						insert("_");
+						Text = "";
+						chars->append(hg);
+						continue;
+					}
 					else
 						Text += hg->ch;
 				}
@@ -816,11 +890,13 @@ void SEditor::loadItemText(PageItem* b)
 	ParagStyles.append(Ali);
 	if (StyledText.count() != 0)
 		emit setProps(0, 0);
+	setUpdatesEnabled(true);
 	setCursorPosition(0, 0);
 }
 
 void SEditor::loadText(QString tx, PageItem* b)
 {
+	setUpdatesEnabled(false);
 	struct PtiSmall *hg;
 	QString Text = "";
 	StyledText.clear();
@@ -866,6 +942,7 @@ void SEditor::loadText(QString tx, PageItem* b)
 	ParagStyles.append(b->Ausrich);
 	if (StyledText.count() != 0)
 		emit setProps(0, 0);
+	setUpdatesEnabled(true);
 	setCursorPosition(0, 0);
 }
 
@@ -873,6 +950,7 @@ void SEditor::updateAll()
 {
 	if (StyledText.count() == 0)
 		return;
+	setUpdatesEnabled(false);
 	int p, i;
 	getCursorPosition(&p, &i);
 	clear();
@@ -946,6 +1024,7 @@ void SEditor::updateAll()
 	setFarbe(Ccol, Csha);
 	setStyle(Csty);
 	insert(Text);
+	setUpdatesEnabled(true);
 	setCursorPosition(p, i);
 }
 
@@ -954,6 +1033,7 @@ void SEditor::updateFromChars(int pa)
 	ChList *chars = StyledText.at(pa);
 	if (chars->count() == 0)
 		return;
+	setUpdatesEnabled(false);
 	int SelStart = 0;
 	int SelEnd = 0;
 	int p, i;
@@ -984,6 +1064,7 @@ void SEditor::updateFromChars(int pa)
 	setStyle(Csty);
 	removeSelection();
 	setAlign(chars->at(0)->cab);
+	setUpdatesEnabled(true);
 	setCursorPosition(p, i);
 }
 
@@ -1233,6 +1314,8 @@ void SEditor::paste()
 		}
 	}
 	updateAll();
+	sync();
+	repaintContents();
 	emit SideBarUp(true);
 	emit SideBarUpdate();
 }
@@ -1351,11 +1434,11 @@ void SToolBColorS::newShadeHandler()
 SToolBStyle::SToolBStyle(QMainWindow* parent) : QToolBar( tr("Character Settings"), parent)
 {
 	SeStyle = new StyleSelect(this);
-	kerningLabel = new QLabel( tr( "Kerning:" ), this, "kerningLabel" );
+	trackingLabel = new QLabel( tr( "Tracking:" ), this, "trackingLabel" );
 	Extra = new MSpinBox( this, 1 );
 	Extra->setValues( -300, 300, 10, 0);
 	Extra->setSuffix( tr( " pt" ) );
-	QToolTip::add( Extra, tr( "Manual Kerning" ) );
+	QToolTip::add( Extra, tr( "Manual Tracking" ) );
 	connect(SeStyle, SIGNAL(State(int)), this, SIGNAL(NewStyle(int)));
 	connect(Extra, SIGNAL(valueChanged(int)), this, SLOT(newKernHandler()));
 }
@@ -1655,6 +1738,8 @@ StoryEditor::StoryEditor(QWidget* parent, ScribusDoc *docc, PageItem *ite)
 	connect(StyleTools, SIGNAL(NewKern(double )), this, SLOT(newTxKern(double )));
 	connect(StyleTools, SIGNAL(NewStyle(int )), this, SLOT(newTxStyle(int )));
 	Editor->setFocus();
+	if (!ScApp->ClipB->text(QClipboard::Clipboard).isNull())
+		PasteAvail();
 }
  
 /** 10/12/2004 - pv - #1203: wrong selection on double click
@@ -1687,6 +1772,9 @@ int StoryEditor::exec()
 	clearWFlags( WDestructiveClose );
 	setWFlags( WShowModal );
 	result = 0;
+	QTextCodec * cdc;
+	cdc = QTextCodec::codecForCStrings();
+	cdc = QTextCodec::codecForLocale();
 	show();
 	Editor->setFocus();
 	qApp->enter_loop();
@@ -1700,9 +1788,14 @@ void StoryEditor::closeEvent(QCloseEvent *)
 	{
 		int t = QMessageBox::warning(this, tr("Warning"),
 									tr("Do you want to save your changes?"),
-									QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel);
+									QMessageBox::Yes|QMessageBox::Default,
+									QMessageBox::No,
+									QMessageBox::Cancel|QMessageBox::Escape);
 		if (t == QMessageBox::Yes)
+		{
+			updateTextFrame();
 			result = QDialog::Accepted;
+		}
 		else if (t == QMessageBox::Cancel)
 			return;
 		else if (t == QMessageBox::No)
@@ -1714,6 +1807,14 @@ void StoryEditor::closeEvent(QCloseEvent *)
 	qApp->exit_loop();
 }
 
+void StoryEditor::keyPressEvent (QKeyEvent * e)
+{
+	if (e->key() == Qt::Key_Escape)
+		this->close();
+	else
+		return QMainWindow::keyReleaseEvent(e);
+}
+
 void StoryEditor::setBackPref()
 {
 	QColor neu = QColor();
@@ -1891,7 +1992,7 @@ void StoryEditor::updateProps(int p, int ch)
 			StrokeTools->TxStroke->setEnabled(false);
 			StrokeTools->PM1->setEnabled(false);
 		}
-		Editor->setAlign(Editor->CurrentABStil);
+		//Editor->setAlign(Editor->CurrentABStil); breaks 1st paragraph bug #1669
 		Editor->setStyle(Editor->CurrentStyle);
 		Editor->setFarbe(Editor->CurrTextFill, Editor->CurrTextFillSh);
 		firstSet = true;
@@ -2057,6 +2158,7 @@ void StoryEditor::Do_fontPrev()
 
 void StoryEditor::Do_leave2()
 {
+	updateTextFrame();
 	result = QDialog::Accepted;
 	hide();
 	qApp->exit_loop();
@@ -2118,6 +2220,8 @@ void StoryEditor::slotFileRevert()
 	{
 		Editor->loadItemText(CurrItem);
 		updateStatus();
+		Editor->sync();
+		Editor->repaintContents();
 	}
 }
 
@@ -2195,12 +2299,6 @@ void StoryEditor::updateTextFrame()
 		nb2 = nb2->NextBox;
 	}
 	Editor->saveItemText(nb);
-	if (doc->Trenner->AutoCheck)
-	{
-		if (doc->Trenner->Language != nb->Language)
-			doc->Trenner->slotNewDict(nb->Language);
-		doc->Trenner->slotHyphenate(nb);
-	}
 	bool rep = doc->RePos;
 	doc->RePos = true;
 	QPixmap pgPix(1, 1);
@@ -2253,6 +2351,8 @@ void StoryEditor::slotEditStyles()
 	connect(Editor, SIGNAL(cursorPositionChanged(int, int)), this, SLOT(updateProps(int, int)));
 	EditorBar->setRepaint(true);
 	EditorBar->doRepaint();
+	Editor->sync();
+	Editor->repaintContents();
 }
 
 void StoryEditor::newAlign(int st)
@@ -2352,6 +2452,8 @@ void StoryEditor::changeAlignSB(int pa, int align)
 		updateProps(0, 0);
 	}
 	modifiedText();
+	Editor->sync();
+	Editor->repaintContents();
 	Editor->setFocus();
 }
 
@@ -2467,6 +2569,8 @@ void StoryEditor::changeAlign()
 		updateProps(0, 0);
 	}
 	modifiedText();
+	Editor->sync();
+	Editor->repaintContents();
 	Editor->setFocus();
 }
 
@@ -2519,6 +2623,8 @@ void StoryEditor::LoadTextFile()
 		EditorBar->setRepaint(true);
 		EditorBar->doRepaint();
 	}
+	Editor->sync();
+	Editor->repaintContents();
 }
 
 void StoryEditor::SaveTextFile()
